diff -uNr FlowScan-1.006.orig/Makefile.PL FlowScan-1.006/Makefile.PL
--- FlowScan-1.006.orig/Makefile.PL	1970-01-01 01:00:00.000000000 +0100
+++ FlowScan-1.006/Makefile.PL	2007-02-24 11:06:43.000000000 +0100
@@ -0,0 +1,11 @@
+use ExtUtils::MakeMaker;
+
+WriteMakefile(
+    'NAME'	=> 'FlowScan',
+    'DISTNAME'  => 'FlowScan',
+    'VERSION_FROM'   => 'FlowScan.pm',
+    'PMLIBDIRS' => ['FlowScan'],
+    'linkext'   => { LINKTYPE=>'' },	# no link needed
+    'dist'      => {'COMPRESS'=>'gzip -9f', 'SUFFIX' => 'gz',
+	            'ZIP'=>'/usr/bin/zip','ZIPFLAGS'=>'-rl'},
+);
--- flowscan-1.006.orig/cf/CampusIO.cf
+++ flowscan-1.006/cf/CampusIO.cf
@@ -16,7 +16,7 @@
 # a comma-seperated list of one (or more) files containing the definitions
 # of "local" subnets, e.g.:
 # LocalSubnetFiles local_nets.boulder
-LocalSubnetFiles bin/local_nets.boulder
+LocalSubnetFiles /etc/flowscan/local_nets.boulder

 # OutputDir (REQUIRED)
 # This is the directory in which RRD files will be written, e.g.:
@@ -72,7 +72,7 @@
 # a comma-seperated list of one (or more) files containing the definitions
 # of "Napster" subnets, e.g.:
 # NapsterSubnetFiles Napster_subnets.boulder
-NapsterSubnetFiles bin/Napster_subnets.boulder
+NapsterSubnetFiles /etc/flowscan/Napster_subnets.boulder

 # NapsterSeconds (OPTIONAL)
 # the number of seconds after which a given campus host has communicated
--- flowscan-1.006.orig/cf/SubNetIO.cf
+++ flowscan-1.006/cf/SubNetIO.cf
@@ -5,7 +5,7 @@
 # a comma-seperated list of one (or more) files containing the definitions
 # of "local" subnets, e.g.:
 # SubnetFiles our_subnets.boulder
-SubnetFiles bin/our_subnets.boulder
+SubnetFiles /etc/flowscan/our_subnets.boulder

 # OutputDir (REQUIRED)
 # This is the directory in which RRD files will be written, e.g.:
--- flowscan-1.006.orig/flowscan.in
+++ flowscan-1.006/flowscan.in
@@ -39,7 +39,8 @@
 $c->directive('WaitSeconds');
 $c->required('FlowFileGlob');
 $c->required('ReportClasses');
-$c->load("${FindBin::Bin}/${FindBin::Script}.cf");
+#$c->load("${FindBin::Bin}/${FindBin::Script}.cf");
+$c->load("/etc/${FindBin::Script}/${FindBin::Script}.cf");
 $flowfileglob = $c->value('FlowFileGlob');
 $opt_w = $c->value('WaitSeconds');
 $opt_v = $c->value('Verbose');
--- flowscan-1.006.orig/FlowScan.pm
+++ flowscan-1.006/FlowScan.pm
@@ -15,7 +15,7 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

-# $Id: FlowScan.pm,v 1.5 2001/02/11 20:41:19 dplonka Exp $
+# $Id: FlowScan.pm,v 1.6 2001/03/27 20:48:01 dplonka Exp $
 # Dave Plonka <plonka@doit.wisc.edu>

 use strict;
@@ -29,7 +29,7 @@
 @FlowScan::ISA=qw(Exporter);
 @FlowScan::EXPORT_OK=qw(ip2name);
 # convert the RCS revision to a reasonable Exporter VERSION:
-'$Revision: 1.5 $' =~ m/(\d+)\.(\d+)/ && (( $FlowScan::VERSION ) = sprintf("%d.%03d", $1, $2));
+'$Revision: 1.6 $' =~ m/(\d+)\.(\d+)/ && (( $FlowScan::VERSION ) = sprintf("%d.%03d", $1, $2));

 =head1 NAME

@@ -190,7 +190,7 @@

 =head1 VERSION

-The version number is the module file RCS revision number (B<$Revision: 1.5 $>)
+The version number is the module file RCS revision number (B<$Revision: 1.6 $>)
 with the minor number printed right justified with leading zeroes to 3
 decimal places.  For instance, RCS revision 1.1 would yield a package version
 number of 1.001.
--- flowscan-1.006.orig/SubNetIO.pm
+++ flowscan-1.006/SubNetIO.pm
@@ -143,7 +143,8 @@
 $c->directive('Verbose');
 $c->directive('TopN');
 $c->directive('ReportPrefixFormat');
-$c->load("${FindBin::Bin}/SubNetIO.cf");
+#$c->load("${FindBin::Bin}/SubNetIO.cf");
+$c->load("/etc/${FindBin::Script}/SubNetIO.cf");

 if (1 <= $c->value('Verbose')) {
    $SubNetIO::verbose = 1


--- flowscan-1.006.orig/CampusIO.pm
+++ flowscan-1.006/CampusIO.pm
@@ -145,8 +145,8 @@
 by name or number.  E.g., it is recommended that it contain at least
 the services shown here:

-   # TCPServices ftp-data, ftp, smtp, nntp, http, 7070, 554
-   TCPServices ftp-data, ftp, smtp, nntp, http, 7070, 554
+   # TCPServices ftp-data, ftp, smtp, nntp, www, 7070, 554
+   TCPServices ftp-data, ftp, smtp, nntp, www, 7070, 554

 =item B<UDPServices>

@@ -402,7 +402,8 @@
 $c->directive('BGPDumpFile');
 $c->directive('ASNFile');
 $c->directive('WebProxyIfIndex');
-$c->load("${FindBin::Bin}/CampusIO.cf");
+#$c->load("${FindBin::Bin}/CampusIO.cf");
+$c->load("/etc/${FindBin::Script}/CampusIO.cf");

 if (1 <= $c->value('Verbose')) {
    $CampusIO::verbose = 1